if length(dbstack)==1 % True if run as script in console
  clear 
  close all
  NumEigs=15; % Number of eigenvalues (and eigenvectors) to find
  N=75;
  sigma='sm';
  nfig=100;
  demo=false;
  E = 21e5; nu = 0.45; %nu = 0.28;
end
mu= E/(2*(1+nu));
lambda = E*nu/((1+nu)*(1-2*nu));
%  
isolines=true;
geofile='barwith4holes';
fprintf('------------------------------------------------------\n'); 
fprintf('      2D elasticity eBVP on mesh from %s.geo\n',geofile);
fprintf('         using hypercube mesh\n\n');
fprintf('             -div(sigma(u)) = k*u \n');
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [1]\n');
fprintf('       u_1 = u_2 = 0 ,\n');
fprintf('   * Neumann on [2,3,4,12,14,16,18]\n');
fprintf('       sigma(u).n = 0 ,\n');
fprintf(' with lambda=%g, mu=%g\n',lambda,mu);
fprintf('------------------------------------------------------\n'); 

[curpath,~,~]=fileparts(mfilename('fullpath'));
dim=2;
tstart=tic();
meshfile=gmsh.buildmesh2d(geofile,N,'geodir',[curpath,filesep,'geodir'],'meshdir',[curpath,filesep,'meshdir']);
Th=siMesh(meshfile);
T(1)=toc(tstart);
fprintf('*** Generate and read mesh file in : %.3f(s)\n',T(1));
info(Th)

tstart=tic();
Hop=Hoperator();
Hop.opStiffElas(dim,lambda,mu);
pde=PDEelt(Hop);
bvp=BVP(Th,pde);
bvp.setDirichlet( 1, 0.,1:2);
T(2)=toc(tstart);
fprintf('*** Set eBVP in : %.3f(s)\n',T(2));

% Computation of numerical eigenvectors and eigenvalues
tstart=tic();
[eVec,eVal,flag]=fc_vfemp1.addon.eigs.solve(bvp,NumEigs,sigma);
T(3)=toc(tstart);
if flag~=0, warning('function eigs trouble: not all eigenvalues converged!');end
fprintf('*** Solve eBVP with %d eigenvalues in : %.3f(s)\n',NumEigs,T(3));

tstart=tic();
[eVec,eVal]=fc_vfemp1.addon.eigs.splitsort(bvp,eVec,eVal);
fc_vfemp1.addon.eigs.plot(Th,eVec,eVal,'nfig',nfig,'demo',demo)
drawnow
T(4)=toc(tstart);
fprintf('*** Graphical representations in : %.3f(s)\n',T(4));

if nfig>0
  figure(1)
  Th.plotmesh('color',0.9*[1,1,1])
  hold on
  axis image
  Th.plotmesh('d',1,'legend',true,'linewidth',2)
end