if length(dbstack)==1
  clear 
  close all
  NumEigs=12; % Number of eigenvalues (and eigenvectors) to find
  N=150;
  nfig=100;
  sigma='sm';
  demo=false;
end

geofile='Lshape';
fprintf('------------------------------------------------------\n'); 
fprintf('Running sample: %s\n',mfilename());
fprintf('------------------------------------------------------\n'); 
fprintf('      2D Laplacian eBVP using gmsh with %s.geo (N=%d) :\n\n',geofile,N);
fprintf('             -Laplacian(u) = lambda*u \n');
fprintf('        with Dirichlet boundary conditions\n');
fprintf('------------------------------------------------------\n');

[curpath,~,~]=fileparts(mfilename('fullpath'));
tstart=tic();
meshfile=gmsh.buildmesh2d(geofile,N,'geodir',[curpath,filesep,'geodir'],'meshdir',[curpath,filesep,'meshdir']);
Th=siMesh(meshfile,'dim',2,'format','gmsh');
T(1)=toc(tstart);
fprintf('*** Generate and read mesh file in : %.3f(s)\n',T(1));
info(Th);

tstart=tic();
dim=2;d=2;
Lop=Loperator(dim,d,{1,0;0,1},[],[],[]);
pde=PDEelt(Lop);
bvp=BVP(Th,pde);
BDLabels=Th.sThlab(Th.find(1));
for lab=BDLabels, bvp.setDirichlet( lab, 0);end
T(2)=toc(tstart);
fprintf('*** Set eBVP in : %.3f(s)\n',T(2));

% Computation of numerical eigenvectors and eigenvalues
tstart=tic();
[eVec,lambda,flag]=fc_vfemp1.addon.eigs.solve(bvp,NumEigs,sigma);
T(3)=toc(tstart);
if flag~=0, warning('function eigs trouble: not all eigenvalues converged!');end
fprintf('*** Solve eBVP with %d eigenvalues in : %.3f(s)\n',NumEigs,T(3));

tstart=tic();
[eVec,lambda]=fc_vfemp1.addon.eigs.splitsort(bvp,eVec,lambda);
fc_vfemp1.addon.eigs.plot(Th,eVec,lambda,'demo',demo)
drawnow
T(4)=toc(tstart);
fprintf('*** Graphical representations in : %.3f(s)\n',T(4));

if ~demo
  figure(1)
  Th.plotmesh('color',0.9*[1,1,1])
  hold on
  axis image
  Th.plotmesh('d',1,'legend',true,'linewidth',2)
end